@@ -4,16 +4,16 @@
 # Portions Copyright 2007-2008, Sun Microsystems, Inc.
 #
 # This library is free software; you can redistribute it and/or
-# modify it under the terms of the GNU Library General Public
+# modify it under the terms of the GNU Lesser General Public
 # License as published by the Free Software Foundation; either
-# version 2 of the License, or (at your option) any later version.
+# version 2.1 of the License, or (at your option) any later version.
 #
 # This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Library General Public License for more details.
+# Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Library General Public
+# You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the
 # Free Software Foundation, Inc., Franklin Street, Fifth Floor,
 # Boston MA  02110-1301 USA.
@@ -26,10 +26,10 @@ ACSS definitions into engine-specific markup codes.
 
 """
 
-__id__ = "$Id: acss.py 4563 2009-02-16 21:50:08Z wwalker $"
+__id__ = "$Id$"
 __author__ = "T. V. Raman"
-__version__ = "$Revision: 4563 $"
-__date__ = "$Date: 2009-02-16 16:50:08 -0500 (Mon, 16 Feb 2009) $"
+__version__ = "$Revision$"
+__date__ = "$Date$"
 __copyright__ = "Copyright (c) 2005-2008 Google Inc."
 __license__ = "LGPL"
 
@@ -51,7 +51,7 @@ class ACSS(dict):
     settings = {
         FAMILY :        None,
         RATE :          50,
-        GAIN :          100,
+        GAIN :          10,
         AVERAGE_PITCH : 5,
         PITCH_RANGE :   5,
         STRESS :        5,
@@ -63,19 +63,23 @@ class ACSS(dict):
         """Create and initialize ACSS structure."""
         dict.__init__(self)
         props = props or {}
-        for k in props:
-            if k in ACSS.settings:
-                # Do a 'deep copy' of the family.  Otherwise,
-                # the new ACSS shares the actual data with the
-                # props passed in.  This can cause unexpected
-                # side effects.
-                #
-                if k == ACSS.FAMILY:
-                    self[k] = {}
-                    for j in props[k].keys():
-                        self[k][j] = props[k][j]
-                else:
-                    self[k] = props[k]
+        if props:
+            for k in props:
+                if k in ACSS.settings:
+                    # Do a 'deep copy' of the family.  Otherwise,
+                    # the new ACSS shares the actual data with the
+                    # props passed in.  This can cause unexpected
+                    # side effects.
+                    #
+                    if k == ACSS.FAMILY:
+                        self[k] = {}
+                        for j in props[k].keys():
+                            self[k][j] = props[k][j]
+                    else:
+                        self[k] = props[k]
+        else:
+            self['established'] = False
+
 
     def __setitem__ (self, key, value):
         """Update name when we change values."""
